@@ -4,7 +4,7 @@ import requests
 import cfscrape
 import re
 from xml.etree import ElementTree
-from ..excepts import IsStandalone, FetcherNotFound, EmptyChapter
+from ..excepts import IsStandalone, FetcherNotFound, EmptyChapter, DelayedRelease
 from ..Pyscandl import Pyscandl
 from ..fetchers import FetcherEnum
 
@@ -48,14 +48,12 @@ class Controller:
 		with open(f"{os.path.dirname(sys.modules['pyscandl.modules.autodl'].__file__)}/db.json", "w") as data:
 			json.dump(self.db, data, indent=4, sort_keys=True)
 
-	def add(self, name:str, rss:str, link:str, fetcher:str, chapters:list=None, archived=False):
+	def add(self, name:str, link:str, fetcher:str, chapters:list=None, archived=False):
 		"""
 		Adds a new scan entry to the ``db.json`` file.
 
 		:param name: name of the manga
 		:type name: str
-		:param rss: rss link of the manga
-		:type rss: str
 		:param link: link to the page of the manga *(same link that is used for the -l arg in other uses of pyscandl)*
 		:type link: str
 		:param fetcher: name of the associated fetcher
@@ -77,22 +75,19 @@ class Controller:
 		if fetcher.lower() in ["nhentai"]:
 			raise IsStandalone(name)
 		self.db[name] = {
-			"rss": rss,
 			"link": link,
 			"fetcher": fetcher.upper(),
 			"chapters": sorted(chapters, reverse=True),
 			"archived": archived
 		}
 
-	def edit(self, name:str, rss:str=None, link:str=None, fetcher=None, chapters:list=None, archived=None):
+	def edit(self, name:str, link:str=None, fetcher=None, chapters:list=None, archived=None):
 		"""
 		Edits an already existing entry in the ``db.json`` file.
 		The :param name: is mandatory to find the correct entry and every other parameter specified will overwrite the existing values.
 
 		:param name: name of the manga
 		:type name: str
-		:param rss: rss link of the manga
-		:type rss: str
 		:param link: link to the page of the manga *(same link that is used for the -l arg in other uses of pyscandl)*
 		:type link: str
 		:param fetcher: name of the associated fetcher
@@ -105,8 +100,6 @@ class Controller:
 		:raises IsStandalone: the specified fetcher is a standalone fetcher
 		"""
 
-		if rss is not None:
-			self.db.get(name)["rss"] = rss
 		if link is not None:
 			self.db.get(name)["link"] = link
 		if fetcher is not None:
@@ -133,34 +126,12 @@ class Controller:
 
 		self.missing_chaps.clear()
 		manga = self.db.get(name)
-		if manga.get("fetcher").lower() in ["fanfox", "fanfox_mono"]:
-			xml = ElementTree.fromstring(requests.get(manga.get("rss")).content)
-			for chapter in xml.iter("item"):
-				nb = chapter.find("link").text.split("/")[-2][1:]
-				if "." in nb:
-					nb = float(nb)
-				else:
-					nb = int(nb)
-				if nb not in manga.get("chapters"):
-					self.missing_chaps.append(nb)
-		elif manga.get("fetcher").lower() == "mangadex":
-			raw = self.scrapper.get(manga.get("rss")).text
-			if "The Database server is under heavy load and can't serve your request. Please wait a bit and try refreshing the page." in raw:
-				if not self.quiet:
-					print(f"The Database server of mangadex is under heavy load and can't check the chapters of \"{name}\" at the moment.")
-			else:
-				xml = ElementTree.fromstring(raw)
-				for chapter in xml.iter("item"):
-					if chapter.find("description").text.split(" - ")[-1] == "Language: English":
-						# check if it's a chapter
-						if self._re_mgdex_scan.search(chapter.find("title").text):
-							nb = self._re_mgdex_scan.search(chapter.find("title").text).group("chap")
-							if "." in nb:
-								nb = float(nb)
-							else:
-								nb = int(nb)
-							if nb not in manga.get("chapters"):
-								self.missing_chaps.append(nb)
+
+		manga_fetcher = FetcherEnum.get(manga.get("fetcher"))
+		manga_chapters = manga_fetcher.scan(link=manga.get("link"))
+
+		self.missing_chaps = list(set(manga_chapters) - set(manga.get("chapters")))
+
 		self.missing_chaps.sort()
 		if not self.quiet:
 			if self.missing_chaps:
@@ -214,6 +185,9 @@ class Controller:
 			except EmptyChapter:
 				if not self.quiet:
 					print(f"skipping {name} chapter {self.missing_chaps[chapter_id]}: empty, wont be added in the downloaded list")
+			except DelayedRelease as e:
+				if not self.quiet:
+					print(e)
 
 		# if chapters are left to doawnload proceeds with it
 		if ok:
@@ -239,6 +213,9 @@ class Controller:
 				except EmptyChapter:
 					if not self.quiet:
 						print(f"skipping {name} chapter {self.missing_chaps[chapter_id]}: empty, wont be added in the downloaded list")
+				except DelayedRelease as e:
+					if not self.quiet:
+						print(e)
 
 			downloader.fetcher.quit()
 			self.db.get(name).get("chapters").sort(reverse=True)
