@@ -1,6 +1,9 @@
-from ..excepts import MangaNotFound, EmptyChapter
+from ..excepts import MangaNotFound, EmptyChapter, DelayedRelease, DownedSite
 from .fetcher import Fetcher
 import cfscrape
+import requests
+import json.decoder
+from datetime import datetime
 
 
 class Mangadex(Fetcher):
@@ -20,6 +23,8 @@ class Mangadex(Fetcher):
 		:type chapstart: int/float/str
 
 		:raises MangaNotFound: the scan asked for can't be found
+		:raises EmptyChapter: the chapter you want to download is empty
+		:raises DelayedRelease: the chapter you want to download isn't available yet
 		"""
 
 		super().__init__(link, manga, chapstart)
@@ -38,7 +43,10 @@ class Mangadex(Fetcher):
 
 		self.domain = ".mangadex.org"
 
-		manga_json = self.scrapper.get(f"https://mangadex.org/api/manga/{manga_id}").json()
+		try:
+			manga_json = self.scrapper.get(f"https://mangadex.org/api/manga/{manga_id}").json()
+		except json.decoder.JSONDecodeError:
+			raise DownedSite("Mangadex")
 		if manga_json.get("status") == "Manga ID does not exist.":
 			raise MangaNotFound(manga_id)
 
@@ -65,10 +73,19 @@ class Mangadex(Fetcher):
 		Method used to update the internal info of the parser about the chapter given with the chap_id.
 
 		:param chap_id: id of the chapter we want the info about
+
+		:raises EmptyChapter: the chapter you want to download is empty
+		:raises DelayedRelease: the chapter you want to download isn't available yet
 		"""
 
 		self.npage = 1
-		self._current_chapter_json = self.scrapper.get(f"https://mangadex.org/api/chapter/{chap_id}").json()
+
+
+		try:
+			self._current_chapter_json = self.scrapper.get(f"https://mangadex.org/api/chapter/{chap_id}").json()
+		except json.decoder.JSONDecodeError:
+			raise DownedSite("Mangadex")
+
 		self.chapter_name = self._current_chapter_json.get("title").replace("/", "-")
 
 		self.chapter_number = str(self._current_chapter_json.get("chapter")).split(".")[0].zfill(3)
@@ -80,6 +97,11 @@ class Mangadex(Fetcher):
 
 		# checking if chapter is accessible
 		if not self._img_ids:
+			if self._current_chapter_json.get("status") == "delayed":
+				ts = self._current_chapter_json.get("timestamp")
+				date = datetime.fromtimestamp(ts)
+				raise DelayedRelease(f"{self.manga_name}, chap {self.chapter_number}", date.isoformat(sep=" "))
+
 			raise EmptyChapter(self.manga_name, self.chapter_number)
 
 		self.image = f"{self._img_root}{self._img_ids[0]}"
@@ -137,6 +159,41 @@ class Mangadex(Fetcher):
 
 		return self._chap_id_pos+1 == len(self._ordered_chaps_json)
 
+	@classmethod
+	def scan(cls, link:str=None, manga:str=None):
+
+		header = {
+			"User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.120 Safari/537.36",
+			"Set-Cookie": "domain=.mangadex.org",
+			"Path": "/"
+		}
+
+		if link is not None:
+			if link[-1] == "/":
+				link = link[:-1]
+			manga_id = link.split("/")[-2]
+		elif manga.isdecimal():
+			manga_id = manga
+		else:
+			raise MangaNotFound(manga)
+
+
+		req = requests.get(f"https://mangadex.org/api/manga/{manga_id}", headers=header)
+		if req.status_code == 200:
+			manga_json = req.json()
+		else:
+			raise DownedSite("Mangadex")
+
+		if manga_json.get("status") == "Manga ID does not exist.":
+			raise MangaNotFound(manga_id)
+
+		if manga_json.get("chapter"):
+			chaps = [chap.get("chapter") for chap in manga_json.get("chapter").values() if chap.get("lang_code") == "gb" and chap.get("chapter") != ""]
+		else:
+			return []
+
+		return list({float(chap) if "." in chap else int(chap) for chap in chaps})
+
 	def quit(self):
 		"""
 		Method used to close everything that was used after finishing to use the fetcher
